# TreezorClient::VirtualibansApi

All URIs are relative to *https://sandbox.treezor.com/v1/index.php*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getvirtualiban**](VirtualibansApi.md#getvirtualiban) | **GET** /virtualibans/{id} | get a virtualiban by Id
[**getvirtualibans**](VirtualibansApi.md#getvirtualibans) | **GET** /virtualibans | search virtualibans
[**post_virtual_iban**](VirtualibansApi.md#post_virtual_iban) | **POST** /virtualibans | create a virtual IBAN
[**put_virtual_iban**](VirtualibansApi.md#put_virtual_iban) | **PUT** /virtualibans/{id} | update a Virtual IBAN


# **getvirtualiban**
> InlineResponse20027 getvirtualiban(id)

get a virtualiban by Id

Get a virtualiban from the system by its id.

### Example
```ruby
# load the gem
require 'treezor_client'
# setup authorization
TreezorClient.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['Authorization'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Authorization'] = 'Bearer'
end

api_instance = TreezorClient::VirtualibansApi.new

id = 789 # Integer | VirtualIban's id.


begin
  #get a virtualiban by Id
  result = api_instance.getvirtualiban(id)
  p result
rescue TreezorClient::ApiError => e
  puts "Exception when calling VirtualibansApi->getvirtualiban: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| VirtualIban&#39;s id. | 

### Return type

[**InlineResponse20027**](InlineResponse20027.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **getvirtualibans**
> InlineResponse20027 getvirtualibans(valid_from, opts)

search virtualibans

Get virtualiban that match search criteria.

### Example
```ruby
# load the gem
require 'treezor_client'
# setup authorization
TreezorClient.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['Authorization'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Authorization'] = 'Bearer'
end

api_instance = TreezorClient::VirtualibansApi.new

valid_from = Date.parse('2013-10-20') # Date | The beginning date of validity.

opts = { 
  access_signature: 'access_signature_example', # String | Access signature can be mandatory for specific context. Treezor will contact you if so. More info [here](https://agent.treezor.com/security-authentication). 
  access_tag: 'access_tag_example', # String | Access tag is used for idem potency query. More info [here](https://agent.treezor.com/basics). 
  access_user_id: 56, # Integer | Access user's id is used for user's action restriction. More info [here](https://agent.treezor.com/basics). 
  access_user_ip: 56, # Integer | Access user's ip is used for user's action restriction. More info [here](https://agent.treezor.com/basics). 
  virtual_iban_id: 56, # Integer | VirtualIban's id.
  wallet_id: 56, # Integer | VirtualIban's wallet id.
  type_id: 56, # Integer | VirtualIban's type id.
  tag: 56, # Integer | A tag generated by the client
  reference: 'reference_example', # String | The client's internal reference of the vitual IBAN.
  valid_to: Date.parse('2013-10-20'), # Date | The limit date of validity.
  max_usage: 'max_usage_example', # String | The maximum number of usage authorized.
  max_amount: 3.4, # Float | The maximum amount authorized.
  created_date_from: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | The creation date from which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info [here](https://agent.treezor.com/lists) 
  created_date_to: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | The creation date up to which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info [here](https://agent.treezor.com/lists) 
  updated_date_from: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | The modification date from which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info [here](https://agent.treezor.com/lists) 
  updated_date_to: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | The modification date up to which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info [here](https://agent.treezor.com/lists) 
  page_number: 56, # Integer | Pagination page number. More info [here](https://agent.treezor.com/lists). 
  page_count: 56, # Integer | The number of items per page. More info [here](https://agent.treezor.com/lists). 
  sort_by: 'sort_by_example', # String | The transaction element you want to sort the list with. Default value : createdDate. More info [here](https://agent.treezor.com/lists). 
  sort_order: 'sort_order_example' # String | The order you want to sort the list. * **DESC** for a descending sort * **ASC** for a ascending sort.  Default value : DESC. More info [here](https://agent.treezor.com/lists). 
}

begin
  #search virtualibans
  result = api_instance.getvirtualibans(valid_from, opts)
  p result
rescue TreezorClient::ApiError => e
  puts "Exception when calling VirtualibansApi->getvirtualibans: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **valid_from** | **Date**| The beginning date of validity. | 
 **access_signature** | **String**| Access signature can be mandatory for specific context. Treezor will contact you if so. More info [here](https://agent.treezor.com/security-authentication).  | [optional] 
 **access_tag** | **String**| Access tag is used for idem potency query. More info [here](https://agent.treezor.com/basics).  | [optional] 
 **access_user_id** | **Integer**| Access user&#39;s id is used for user&#39;s action restriction. More info [here](https://agent.treezor.com/basics).  | [optional] 
 **access_user_ip** | **Integer**| Access user&#39;s ip is used for user&#39;s action restriction. More info [here](https://agent.treezor.com/basics).  | [optional] 
 **virtual_iban_id** | **Integer**| VirtualIban&#39;s id. | [optional] 
 **wallet_id** | **Integer**| VirtualIban&#39;s wallet id. | [optional] 
 **type_id** | **Integer**| VirtualIban&#39;s type id. | [optional] 
 **tag** | **Integer**| A tag generated by the client | [optional] 
 **reference** | **String**| The client&#39;s internal reference of the vitual IBAN. | [optional] 
 **valid_to** | **Date**| The limit date of validity. | [optional] 
 **max_usage** | **String**| The maximum number of usage authorized. | [optional] 
 **max_amount** | **Float**| The maximum amount authorized. | [optional] 
 **created_date_from** | **DateTime**| The creation date from which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info [here](https://agent.treezor.com/lists)  | [optional] 
 **created_date_to** | **DateTime**| The creation date up to which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info [here](https://agent.treezor.com/lists)  | [optional] 
 **updated_date_from** | **DateTime**| The modification date from which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info [here](https://agent.treezor.com/lists)  | [optional] 
 **updated_date_to** | **DateTime**| The modification date up to which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info [here](https://agent.treezor.com/lists)  | [optional] 
 **page_number** | **Integer**| Pagination page number. More info [here](https://agent.treezor.com/lists).  | [optional] 
 **page_count** | **Integer**| The number of items per page. More info [here](https://agent.treezor.com/lists).  | [optional] 
 **sort_by** | **String**| The transaction element you want to sort the list with. Default value : createdDate. More info [here](https://agent.treezor.com/lists).  | [optional] 
 **sort_order** | **String**| The order you want to sort the list. * **DESC** for a descending sort * **ASC** for a ascending sort.  Default value : DESC. More info [here](https://agent.treezor.com/lists).  | [optional] 

### Return type

[**InlineResponse20027**](InlineResponse20027.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **post_virtual_iban**
> InlineResponse20027 post_virtual_iban(wallet_id, type_id, opts)

create a virtual IBAN

Create a new virtual IBAN in in the system.

### Example
```ruby
# load the gem
require 'treezor_client'
# setup authorization
TreezorClient.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['Authorization'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Authorization'] = 'Bearer'
end

api_instance = TreezorClient::VirtualibansApi.new

wallet_id = 56 # Integer | The Id Of the Wallet. The Wallet must be in validated status. The wallet must be of type \"payment\" or \"electronic money\"

type_id = 56 # Integer | | Type Id | Virtual IBAN Type| | ---| --- | | 1 | DEBIT | | 2 | CREDIT | 

opts = { 
  access_signature: 'access_signature_example', # String | Access signature can be mandatory for specific context. Treezor will contact you if so. More info [here](https://agent.treezor.com/security-authentication). 
  access_tag: 'access_tag_example', # String | Access tag is used for idem potency query. More info [here](https://agent.treezor.com/basics). 
  access_user_id: 56, # Integer | Access user's id is used for user's action restriction. More info [here](https://agent.treezor.com/basics). 
  access_user_ip: 'access_user_ip_example', # String | Access user's ip is used for user's action restriction. More info [here](https://agent.treezor.com/basics). 
  tag: 56, # Integer | A tag generated by the client
  reference: 'reference_example', # String | The client's internal reference of the vitual IBAN. Less than 255 characters.
  valid_from: Date.parse('2013-10-20'), # Date | The beginning date of validity. The beginning date must not be less than today's date.
  valid_to: Date.parse('2013-10-20'), # Date | The limit date of validity. Cannot be less or equal to the validFrom date.
  max_usage: 56, # Integer | The maximum number of usage authorized. If you want to set no maximum usage limitation you can omit the parameter or set it to null. If you want to limit usage please send an integer in that field. This integer cannot be less than 1.
  max_amount: 3.4 # Float | The maximum amount authorized.If you want to set no maximum usage amount limitation you can omit the parameter or set it to null. If you want to limit the amount please send a DECIMAL (with a point as separator) in that field. This decimal cannot be less than 0.00.
}

begin
  #create a virtual IBAN
  result = api_instance.post_virtual_iban(wallet_id, type_id, opts)
  p result
rescue TreezorClient::ApiError => e
  puts "Exception when calling VirtualibansApi->post_virtual_iban: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **wallet_id** | **Integer**| The Id Of the Wallet. The Wallet must be in validated status. The wallet must be of type \&quot;payment\&quot; or \&quot;electronic money\&quot; | 
 **type_id** | **Integer**| | Type Id | Virtual IBAN Type| | ---| --- | | 1 | DEBIT | | 2 | CREDIT |  | 
 **access_signature** | **String**| Access signature can be mandatory for specific context. Treezor will contact you if so. More info [here](https://agent.treezor.com/security-authentication).  | [optional] 
 **access_tag** | **String**| Access tag is used for idem potency query. More info [here](https://agent.treezor.com/basics).  | [optional] 
 **access_user_id** | **Integer**| Access user&#39;s id is used for user&#39;s action restriction. More info [here](https://agent.treezor.com/basics).  | [optional] 
 **access_user_ip** | **String**| Access user&#39;s ip is used for user&#39;s action restriction. More info [here](https://agent.treezor.com/basics).  | [optional] 
 **tag** | **Integer**| A tag generated by the client | [optional] 
 **reference** | **String**| The client&#39;s internal reference of the vitual IBAN. Less than 255 characters. | [optional] 
 **valid_from** | **Date**| The beginning date of validity. The beginning date must not be less than today&#39;s date. | [optional] 
 **valid_to** | **Date**| The limit date of validity. Cannot be less or equal to the validFrom date. | [optional] 
 **max_usage** | **Integer**| The maximum number of usage authorized. If you want to set no maximum usage limitation you can omit the parameter or set it to null. If you want to limit usage please send an integer in that field. This integer cannot be less than 1. | [optional] 
 **max_amount** | **Float**| The maximum amount authorized.If you want to set no maximum usage amount limitation you can omit the parameter or set it to null. If you want to limit the amount please send a DECIMAL (with a point as separator) in that field. This decimal cannot be less than 0.00. | [optional] 

### Return type

[**InlineResponse20027**](InlineResponse20027.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **put_virtual_iban**
> InlineResponse20027 put_virtual_iban(id, opts)

update a Virtual IBAN

Update Virtual IBAN's information.

### Example
```ruby
# load the gem
require 'treezor_client'
# setup authorization
TreezorClient.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['Authorization'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Authorization'] = 'Bearer'
end

api_instance = TreezorClient::VirtualibansApi.new

id = 56 # Integer | VirtualIban's id.

opts = { 
  access_signature: 'access_signature_example', # String | Access signature can be mandatory for specific context. Treezor will contact you if so. More info [here](https://agent.treezor.com/security-authentication). 
  access_tag: 'access_tag_example', # String | Access tag is used for idem potency query. More info [here](https://agent.treezor.com/basics). 
  access_user_id: 56, # Integer | Access user's id is used for user's action restriction. More info [here](https://agent.treezor.com/basics). 
  access_user_ip: 'access_user_ip_example', # String | Access user's ip is used for user's action restriction. More info [here](https://agent.treezor.com/basics). 
  reference: 'reference_example', # String | The client's internal reference of the vitual IBAN.
  valid_from: Date.parse('2013-10-20'), # Date | The beginning date of validity. Date of validity can be changed. It must follow the rules explained in the POST endpoint.
  valid_to: Date.parse('2013-10-20'), # Date | The limit date of validity. It must follow the rules of creation. It must follow the rules explained in the POST endpoint.
  max_usage: 56, # Integer | The maximum number of usage authorized. It must follow the rules explained in the POST endpoint AND the maximum usage cannot be strictly less than the transaction counter of the Virtual Iban.
  max_amount: 3.4 # Float | The maximum amount authorized. It must follow the rules explained in the POST endpoint AND the maximum amount cannot be strictly less than the cumulated amount of this Virtual Iban.
}

begin
  #update a Virtual IBAN
  result = api_instance.put_virtual_iban(id, opts)
  p result
rescue TreezorClient::ApiError => e
  puts "Exception when calling VirtualibansApi->put_virtual_iban: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| VirtualIban&#39;s id. | 
 **access_signature** | **String**| Access signature can be mandatory for specific context. Treezor will contact you if so. More info [here](https://agent.treezor.com/security-authentication).  | [optional] 
 **access_tag** | **String**| Access tag is used for idem potency query. More info [here](https://agent.treezor.com/basics).  | [optional] 
 **access_user_id** | **Integer**| Access user&#39;s id is used for user&#39;s action restriction. More info [here](https://agent.treezor.com/basics).  | [optional] 
 **access_user_ip** | **String**| Access user&#39;s ip is used for user&#39;s action restriction. More info [here](https://agent.treezor.com/basics).  | [optional] 
 **reference** | **String**| The client&#39;s internal reference of the vitual IBAN. | [optional] 
 **valid_from** | **Date**| The beginning date of validity. Date of validity can be changed. It must follow the rules explained in the POST endpoint. | [optional] 
 **valid_to** | **Date**| The limit date of validity. It must follow the rules of creation. It must follow the rules explained in the POST endpoint. | [optional] 
 **max_usage** | **Integer**| The maximum number of usage authorized. It must follow the rules explained in the POST endpoint AND the maximum usage cannot be strictly less than the transaction counter of the Virtual Iban. | [optional] 
 **max_amount** | **Float**| The maximum amount authorized. It must follow the rules explained in the POST endpoint AND the maximum amount cannot be strictly less than the cumulated amount of this Virtual Iban. | [optional] 

### Return type

[**InlineResponse20027**](InlineResponse20027.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



